diff --git a/comp.py b/comp.py
index f0a1ac2d0d083fc7dcb16682764dfb8aedc48209..4294d66ba2f39fa27b11ae5303dbf8cae5cc80fa 100755
--- a/comp.py
+++ b/comp.py
@@ -175,12 +175,12 @@ class CompJob(ParametricJob):
         ext = os.path.splitext(file)[1]
         if ext==".zip":
             # unzip the source and try to convert text files
-            cmd = 'unzip -a %s -x "*/.svn/*" >/dev/null' % file
+            cmd = 'unzip -a %s -x "*/.git/*" >/dev/null' % file
             sysOutput = os.system(cmd)
             if (sysOutput != 0):
                 self.error("unable to unzip archive %s !" % file)
-            # no conversion for ".svn" database
-            cmd = 'unzip %s "*/.svn/*" >/dev/null' % file
+            # no conversion for ".git" database
+            cmd = 'unzip %s "*/.git/*" >/dev/null' % file
             sysOutput = os.system(cmd)
             if (sysOutput != 0):
                 self.error("unable to unzip archive %s !" % file)